@@ -543,6 +543,41 @@ class GtkDocStringFormatter(Configurable):
         self.gdbus_codegen_sources = config.get_paths('gdbus_codegen_sources')
 
 
+GIDOC_ONLINE_OVERRIDES = {
+    'Gtk': 'https://docs.gtk.org/gtk4/',
+    'Gio': 'https://docs.gtk.org/gio/',
+    'GLib': 'https://docs.gtk.org/glib/',
+    'GObject': 'https://docs.gtk.org/gobject/',
+    'GIRepository': 'https://docs.gtk.org/girepository/',
+    'Soup': 'https://libsoup.org/libsoup-3.0/index.html',
+    'p11-kit': 'https://p11-glue.github.io/p11-glue/p11-kit/manual/',
+    'gi': 'https://gi.readthedocs.io/en/latest/',
+    'libxslt': 'http://xmlsoft.org/xslt/html/',
+    'dbus-glib': 'https://dbus.freedesktop.org/doc/dbus-glib/',
+    'harfbuzz': 'https://harfbuzz.github.io/',
+    'cairo': 'https://www.cairographics.org/manual/',
+    'libxml2': 'http://xmlsoft.org/html/',
+    'Adw': 'https://gnome.pages.gitlab.gnome.org/libadwaita/doc/main/',
+    'PangoOT': 'https://docs.gtk.org/PangoOT/',
+    'PangoFC': 'https://docs.gtk.org/PangoFC/',
+    'PangoFT2': 'https://docs.gtk.org/PangoFT2/',
+    'GdkWayland': 'https://docs.gtk.org/gdk4-wayland/',
+    'Gsk': 'https://docs.gtk.org/gsk4/',
+    'GdkX11': 'https://docs.gtk.org/gdk3-x11/',
+    'GdkPixbuf': 'https://docs.gtk.org/gdk-pixbuf/',
+    'PangoXft': 'https://docs.gtk.org/PangoXft/',
+    'GioUnix': 'https://docs.gtk.org/gio-unix/',
+    'Gdk': 'https://docs.gtk.org/gdk4/',
+    'Atk': 'https://docs.gtk.org/atk/',
+    'PangoCairo': 'https://docs.gtk.org/PangoCairo/',
+    'Atspi': 'https://docs.gtk.org/atspi2/',
+    'GLibUnix': 'https://docs.gtk.org/glib-unix/',
+    'Pango': 'https://docs.gtk.org/Pango/',
+    'GModule': 'https://docs.gtk.org/gmodule/',
+    'GdkPixdata': 'https://lazka.github.io/pgi-docs/GdkPixdata-2.0/'
+}
+
+
 def parse_devhelp_index(dir_):
     path = os.path.join(dir_, os.path.basename(dir_) + '.devhelp2')
     if not os.path.exists(path):
@@ -566,7 +601,11 @@ def parse_devhelp_index(dir_):
             info(
                 'Skipping devhelp index at %s, no online attribute and no name attribute', path)
             return False
-        online = 'https://developer.gnome.org/%s/unstable/' % name
+        if name in GIDOC_ONLINE_OVERRIDES:
+            online = GIDOC_ONLINE_OVERRIDES[name]
+        else:
+            online = 'https://developer.gnome.org/%s/unstable/' % name
+
 
     keywords = dh_root.findall('.//{http://www.devhelp.net/book}keyword')
     for kw in keywords:
@@ -594,6 +633,9 @@ def parse_devhelp_index(dir_):
                         name = '%s::%s' % (split[0], split[1].lstrip('-'))
                     else:
                         name = '%s:%s' % (split[0], split[1].lstrip('-'))
+            # gi-doc
+            elif name.startswith('The ') and name.endswith(f' {type_}'):
+                name = name[len('The '):-len(f' {type_}')]
         elif type_ in ['vfunc']:
             if '#' in link and (language.lower() == 'c' or author == 'hotdoc'):
                 anchor = link.split('#', 1)[1]
@@ -657,6 +699,37 @@ def gather_links():
                         except IOError:
                             pass
 
+    # Newer GLib docs do not advertise links for those types
+    for typename in ['gpointer', 'gconstpointer', 'gboolean', 'gint8', 'guint8', 'gint16', 'guint16', 'gint32', 'guint32', 'gchar', 'guchar', 'gshort', 'gushort', 'gint', 'guint', 'gfloat', 'gdouble', 'gsize', 'gssize', 'goffset', 'gintptr', 'guintptr', 'glong', 'gulong', 'gint64', 'guint64',]:
+        if not typename in GTKDOC_HREFS:
+            GTKDOC_HREFS[typename] = f"https://docs.gtk.org/glib/types.html#{typename}"
+
+    for numerical_type in 'INT', 'SHORT', 'LONG', 'INT8', 'INT16', 'INT32', 'INT64', 'SSIZE', 'OFFSET', 'FLOAT', 'DOUBLE':
+        GTKDOC_HREFS[f'G_MIN{numerical_type}'] = f'https://web.mit.edu/barnowl/share/gtk-doc/html/glib/glib-Limits-of-Basic-Types.html#G-MIN{numerical_type}:CAPS'
+        GTKDOC_HREFS[f'G_MAX{numerical_type}'] = f'https://web.mit.edu/barnowl/share/gtk-doc/html/glib/glib-Limits-of-Basic-Types.html#G-MAX{numerical_type}:CAPS'
+
+    for numerical_type in 'UINT', 'USHORT', 'ULONG', 'UINT8', 'UINT16', 'UINT32', 'UINT64', 'SIZE':
+        GTKDOC_HREFS[f'G_MAX{numerical_type}'] = f'https://web.mit.edu/barnowl/share/gtk-doc/html/glib/glib-Limits-of-Basic-Types.html#G-MAX{numerical_type}:CAPS'
+
+    for gtype in ['INVALID', 'NONE', 'INTERFACE', 'CHAR', 'UCHAR', 'BOOLEAN', 'INT', 'UINT', 'LONG', 'ULONG', 'INT64', 'UINT64', 'ENUM', 'FLAGS', 'FLOAT', 'DOUBLE', 'STRING', 'POINTER', 'BOXED', 'PARAM', 'OBJECT', 'GTYPE']:
+        GTKDOC_HREFS[f'G_TYPE_{gtype}'] = f'https://web.mit.edu/barnowl/share/gtk-doc/html/gobject/gobject-Type-Information.html#G-TYPE-{gtype}:CAPS'
+
+    GTKDOC_HREFS['gchararray'] = 'https://web.mit.edu/barnowl/share/gtk-doc/html/gobject/gobject-Standard-Parameter-and-Value-Types.html#gchararray'
+    GTKDOC_HREFS['GAsyncReadyCallback'] = 'https://docs.gtk.org/gio/callback.AsyncReadyCallback.html'
+    GTKDOC_HREFS['g_auto'] = 'https://docs.gtk.org/glib/auto-cleanup.html#variable-declaration'
+    GTKDOC_HREFS['g_autoptr'] = 'https://docs.gtk.org/glib/auto-cleanup.html#variable-declaration'
+    GTKDOC_HREFS['GCompareDataFunc'] = 'https://docs.gtk.org/glib/callback.CompareDataFunc.html'
+    GTKDOC_HREFS['GCompareFunc'] = 'https://docs.gtk.org/glib/callback.CompareFunc.html'
+    GTKDOC_HREFS['GFunc'] = 'https://docs.gtk.org/glib/callback.Func.html'
+    GTKDOC_HREFS['GSourceFunc'] = 'https://docs.gtk.org/glib/callback.SourceFunc.html'
+    GTKDOC_HREFS['GSocketSourceFunc'] = 'https://docs.gtk.org/gio/callback.SocketSourceFunc.html'
+    GTKDOC_HREFS['GDestroyNotify'] = 'https://docs.gtk.org/glib/callback.DestroyNotify.html'
+    GTKDOC_HREFS['G_GNUC_NO_INSTRUMENT'] = 'https://web.mit.edu/barnowl/share/gtk-doc/html/glib/glib-Miscellaneous-Macros.html#G-GNUC-NO-INSTRUMENT:CAPS'
+
+    for define in ['TRUE', 'FALSE', 'NULL']:
+        if not define in GTKDOC_HREFS:
+            GTKDOC_HREFS[define] = f'https://web.mit.edu/barnowl/share/gtk-doc/html/glib/glib-Standard-Macros.html#{define}:CAPS'
+
 
 def search_online_links(resolver, name):
     href = GTKDOC_HREFS.get(name)
